@@ -2,6 +2,6 @@
 
 __author__ = """Jim Vogel"""
 __email__ = "james.vogel@capspire.com"
-__version__ = "0.1.8"
+__version__ = "0.1.11"
 
-from .tank_forecaster import generate_forecast
+from .tank_forecaster import forecast
